@@ -46,7 +46,6 @@
 #include "libedata-book/e-data-book-view.h"
 #include "e-book-backend-ews.h"
 #include "e-book-backend-sqlitedb.h"
-#include "e-book-backend-ews-utils.h"
 #include "lzx/ews-oal-decompress.h"
 #include "ews-oab-decoder.h"
 #include "e-ews-item-change.h"
@@ -156,6 +155,19 @@ ews_remove_attachments (const gchar *attachment_dir)
 	return TRUE;
 }
 
+static gboolean
+book_view_notify_status (EDataBookView *view,
+                         gpointer user_data)
+{
+	const gchar *status = (const gchar *) user_data;
+
+	if (!view)
+		return TRUE;
+	e_data_book_view_notify_progress (view, -1, status);
+
+	return TRUE;
+}
+
 static const struct phone_field_mapping {
 	EContactField field;
 	const gchar *element;
@@ -1658,13 +1670,12 @@ ews_gal_store_contact (EContact *contact,
 	if (data->collected_length == 1000 || percent >= 100) {
 		GSList *l;
 		gchar *status_message = NULL;
-		EDataBookView *book_view = e_book_backend_ews_utils_get_book_view (E_BOOK_BACKEND (data->cbews));
 
 		d(g_print ("GAL adding contacts, percent complete : %d \n", percent);)
 
 		status_message = g_strdup_printf (_("Downloading contacts in %s %d%% completed... "), priv->folder_name, percent);
-		if (book_view)
-			e_data_book_view_notify_progress (book_view, -1, status_message);
+		e_book_backend_foreach_view (E_BOOK_BACKEND (data->cbews), book_view_notify_status, status_message);
+		g_free (status_message);
 
 		data->contact_collector = g_slist_reverse (data->contact_collector);
 		e_book_backend_sqlitedb_add_contacts (priv->ebsdb, priv->folder_id, data->contact_collector, FALSE, error);
@@ -1672,10 +1683,6 @@ ews_gal_store_contact (EContact *contact,
 		for (l = data->contact_collector; l != NULL; l = g_slist_next (l))
 			e_book_backend_notify_update (E_BOOK_BACKEND (data->cbews), E_CONTACT (l->data));
 
-		/* reset data */
-		if (book_view)
-			e_data_book_view_unref (book_view);
-		g_free (status_message);
 		g_slist_foreach (data->contact_collector, (GFunc) g_object_unref, NULL);
 		g_slist_free (data->contact_collector);
 		data->contact_collector = NULL;
@@ -2151,15 +2158,13 @@ ebews_start_sync (gpointer data)
 	gchar *sync_state, *status_message = NULL;
 	gboolean includes_last_item;
 	GError *error = NULL;
-	EDataBookView *book_view;
 
 	ebews = (EBookBackendEws *) data;
 	priv = ebews->priv;
 
 	status_message = g_strdup (_("Syncing contacts..."));
-	book_view = e_book_backend_ews_utils_get_book_view (E_BOOK_BACKEND (ebews));
-	if (book_view)
-		e_data_book_view_notify_progress (book_view, -1, status_message);
+	e_book_backend_foreach_view (E_BOOK_BACKEND (ebews), book_view_notify_status, status_message);
+	g_free (status_message);
 
 	sync_state = e_book_backend_sqlitedb_get_sync_data (priv->ebsdb, priv->folder_id, NULL);
 	do
@@ -2201,16 +2206,10 @@ ebews_start_sync (gpointer data)
 		e_book_backend_sqlitedb_set_sync_data (priv->ebsdb, priv->folder_id, sync_state, &error);
 	} while (!error && !includes_last_item);
 
-	if (book_view) {
-		e_data_book_view_notify_complete (book_view, error);
-		e_data_book_view_unref (book_view);
-	}
-
 	if (!error)
 		e_book_backend_sqlitedb_set_is_populated (priv->ebsdb, priv->folder_id, TRUE, &error);
 
 	g_free (sync_state);
-	g_free (status_message);
 
 	if (error) {
 		g_warning ("Error Syncing Contacts: Folder %s Error: %s", priv->folder_id, error->message);
@@ -2565,7 +2564,7 @@ e_book_backend_ews_authenticate_user (EBookBackend *backend,
                                       GCancellable *cancellable,
                                       ECredentials *credentials)
 {
-	EBookBackendEws *ebgw;
+	EBookBackendEws *ebews;
 	EBookBackendEwsPrivate *priv;
 	EEwsConnection *cnc = NULL;
 	ESource *esource;
@@ -2576,10 +2575,10 @@ e_book_backend_ews_authenticate_user (EBookBackend *backend,
 	const gchar *host_url;
 	const gchar *read_only;
 
-	ebgw = E_BOOK_BACKEND_EWS (backend);
-	priv = ebgw->priv;
+	ebews = E_BOOK_BACKEND_EWS (backend);
+	priv = ebews->priv;
 
-	if (!ebgw->priv->is_online) {
+	if (!ebews->priv->is_online) {
 		e_book_backend_notify_opened (backend, EDB_ERROR (SUCCESS));
 		return;
 	}
@@ -2744,11 +2743,11 @@ e_book_backend_ews_new (void)
 static void
 e_book_backend_ews_dispose (GObject *object)
 {
-	EBookBackendEws *bgw;
+	EBookBackendEws *bews;
 	EBookBackendEwsPrivate *priv;
 
-	bgw = E_BOOK_BACKEND_EWS (object);
-	priv = bgw->priv;
+	bews = E_BOOK_BACKEND_EWS (object);
+	priv = bews->priv;
 
 	if (priv->cnc) {
 		g_object_unref (priv->cnc);
